
# Examples

- Minimal example [[source code](https://github.com/spirali/nelsie/blob/main/examples/minimal/minimal.py)
]
- Demonstration of features [[PDF](https://spirali.github.io/nelsie/pdf/bigdemo.pdf), [source code](https://github.com/spirali/nelsie/blob/main/examples/bigdemo/bigdemo.py)]
